function commonSubmitArgs = getCommonSubmitArgs(cluster)
% Get any additional submit arguments for the Slurm sbatch command
% that are common to both independent and communicating jobs.

% Copyright 2016-2017 The MathWorks, Inc.

commonSubmitArgs = '';

% Append any arguments provided by the AdditionalSubmitArgs field of cluster.AdditionalProperties.
if isprop(cluster.AdditionalProperties, 'AdditionalSubmitArgs')
    extraArgs = cluster.AdditionalProperties.AdditionalSubmitArgs;
    if ~isempty(extraArgs) && ischar(extraArgs)
        commonSubmitArgs = strtrim([commonSubmitArgs, ' ', extraArgs]);
    end
end

% You may wish to support further cluster.AdditionalProperties fields here
% and modify the submission command arguments accordingly.

%%% modifed by SH to integrate with CARL cluster (Nov 2017)

% possible parameters can be added here as default
defaultPartition = '';
defaultRuntime = '24:0:0';
defaultMemory = '2G';
defaultDiskspace='50M';
defaultTasksPerNode=0;
defaultMailUser='';
defaultMailType='ALL';

% handle in input parser object
p = inputParser;

% possible parameters can be added here for parsing
addParameter(p, 'partition', defaultPartition, @ischar); 
addParameter(p, 'runtime', defaultRuntime, @ischar);
addParameter(p, 'memory', defaultMemory, @ischar);
addParameter(p, 'diskspace', defaultDiskspace, @ischar);
addParameter(p, 'taskspernode', defaultTasksPerNode, @isnumeric);
addParameter(p, 'mailuser', defaultMailUser, @ischar);
addParameter(p, 'mailtype', defaultMailType, @ischar);

% check if a parameter was set in cluster.AdditionalProperties
arg=struct();
for i = 1:length(p.Parameters)
  curr = p.Parameters{i};
  if isprop(cluster.AdditionalProperties, curr)
     arg.(curr) = cluster.AdditionalProperties.(curr);
  end
end

% parse the list in arg into parser object p
parse(p,arg);

% output for user to verify settings
if strcmp(p.Results.partition, defaultPartition)
  disp(['partition    = NONE selected (default)'])
else
  disp(['partition    = ', p.Results.partition])
end

if strcmp(p.Results.runtime, defaultRuntime)
  disp(['runtime      = ', p.Results.runtime, ' (default)'])
else
  disp(['runtime      = ', p.Results.runtime])
end

if strcmp(p.Results.memory, defaultMemory)
  disp(['memory       = ', p.Results.memory, ' (default)'])
else
  disp(['memory       = ', p.Results.memory])
end

if strcmp(p.Results.diskspace, defaultDiskspace)
  disp(['diskspace    = ', p.Results.diskspace, ' (default)'])
else
  disp(['diskspace    = ', p.Results.diskspace])
end

if (p.Results.taskspernode > 0)
  disp(['taskspernode = ', int2str(p.Results.taskspernode)])
end 

pattern='[A-Z0-9._%+-]{1,64}@(?:[A-Z0-9-]+\.){1,8}[A-Z]{2,63}';
if ~strcmp(p.Results.mailuser,regexpi(p.Results.mailuser,pattern,'match'))
  disp 'Cannot validate e-mail address in mailuser option, mailuser will not be used'
  p.Results.mailuser=''
end

if strcmp(p.Results.mailuser, defaultMailUser)
  disp(['mailuser     = NONE (default)'])
  disp(['mailtype     = NONE (default)'])
else
  disp(['mailuser     = ', p.Results.mailuser])
  if strcmp(p.Results.mailtype, defaultMailType)
    disp(['mailtype     = ', p.Results.mailtype, ' (default)'])
  else
	disp(['mailtype     = ', p.Results.mailtype])
  end
end


% create list of extra arguments
% the following list can be expanded easily by adding lines to the
% [] command
extraSubmitArgs = '';    % initialize string
extraSubmitArgs = [ extraSubmitArgs ...
    sprintf('--mem-per-cpu=%s ', p.Results.memory) ...
    sprintf('--time=%s ', p.Results.runtime) ...
    sprintf('--gres=tmpdir:%s ', p.Results.diskspace) ...
    ];
% add parameters based on value
if (~isempty(p.Results.partition))
    extraSubmitArgs = [ extraSubmitArgs ...
		sprintf('--partition=%s ', p.Results.partition) ...
		];
end
if (p.Results.taskspernode > 0)
    extraSubmitArgs = [ extraSubmitArgs ...
        sprintf('--ntasks-per-node=%d ', p.Results.taskspernode) ];
end
if (~isempty(p.Results.mailuser))
    extraSubmitArgs = [ extraSubmitArgs ...
        sprintf('--mail-user=%s ', p.Results.mailuser) ...
        sprintf('--mail-type=%s ', p.Results.mailtype) ...
		];
end

% add extraSubmitArgs to final result commonSubmitArgs
if ~isempty(extraSubmitArgs) && ischar(extraSubmitArgs)
    commonSubmitArgs = strtrim([commonSubmitArgs, ' ', extraSubmitArgs]);
end


